==> jc-1.4.0.tar.gz: javax/xml/parsers/ParserConfigurationException.h <==
// public class javax.xml.parsers.ParserConfigurationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 11ff704e941b23d0 javax_xml_parsers_ParserConfigurationException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_xml_parsers_ParserConfigurationException_H_
#define _JC_javax_xml_parsers_ParserConfigurationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_xml_parsers_ParserConfigurationException$sub_refs	_jc_javax_xml_parsers_ParserConfigurationException$sub_refs;
typedef struct _jc_javax_xml_parsers_ParserConfigurationException$sub_nonrefs	_jc_javax_xml_parsers_ParserConfigurationException$sub_nonrefs;
typedef struct _jc_javax_xml_parsers_ParserConfigurationException$refs	_jc_javax_xml_parsers_ParserConfigurationException$refs;
typedef struct _jc_javax_xml_parsers_ParserConfigurationException$nonrefs	_jc_javax_xml_parsers_ParserConfigurationException$nonrefs;
typedef struct _jc_javax_xml_parsers_ParserConfigurationException$object	_jc_javax_xml_parsers_ParserConfigurationException$object;

typedef const struct _jc_javax_xml_parsers_ParserConfigurationException$vmethods	_jc_javax_xml_parsers_ParserConfigurationException$vmethods;
typedef const struct _jc_javax_xml_parsers_ParserConfigurationException$vtable	_jc_javax_xml_parsers_ParserConfigurationException$vtable;
typedef const struct _jc_javax_xml_parsers_ParserConfigurationException$vtype	_jc_javax_xml_parsers_ParserConfigurationException$vtype;

// Constructors
extern void _jc_javax_xml_parsers_ParserConfigurationException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_parsers_ParserConfigurationException$object *);
extern void _jc_javax_xml_parsers_ParserConfigurationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_xml_parsers_ParserConfigurationException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_xml_parsers_ParserConfigurationException$vmethods {
};

// Vtable
struct _jc_javax_xml_parsers_ParserConfigurationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_xml_parsers_ParserConfigurationException$vmethods	javax_xml_parsers_ParserConfigurationException;
};

// Vtype
struct _jc_javax_xml_parsers_ParserConfigurationException$vtype {
	_jc_type			type;
	_jc_javax_xml_parsers_ParserConfigurationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_parsers_ParserConfigurationException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_parsers_ParserConfigurationException$refs {
    _jc_javax_xml_parsers_ParserConfigurationException$sub_refs	javax_xml_parsers_ParserConfigurationException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_parsers_ParserConfigurationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_parsers_ParserConfigurationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_xml_parsers_ParserConfigurationException$sub_nonrefs	javax_xml_parsers_ParserConfigurationException;
};

// Object instance structure
struct _jc_javax_xml_parsers_ParserConfigurationException$object {
	_jc_javax_xml_parsers_ParserConfigurationException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_parsers_ParserConfigurationException$vtype	*vtype;
	_jc_javax_xml_parsers_ParserConfigurationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_parsers_ParserConfigurationException$vtype _jc_javax_xml_parsers_ParserConfigurationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_parsers_ParserConfigurationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_parsers_ParserConfigurationException$class_object;

#endif	/* _JC_javax_xml_parsers_ParserConfigurationException_H_ */

==> jc-1.4.6.tar.gz: javax/xml/parsers/ParserConfigurationException.h <==
// public class javax.xml.parsers.ParserConfigurationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 11ff704e941b23d0 javax_xml_parsers_ParserConfigurationException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_xml_parsers_ParserConfigurationException_H_
#define _JC_javax_xml_parsers_ParserConfigurationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_xml_parsers_ParserConfigurationException$sub_refs	_jc_javax_xml_parsers_ParserConfigurationException$sub_refs;
typedef struct _jc_javax_xml_parsers_ParserConfigurationException$sub_nonrefs	_jc_javax_xml_parsers_ParserConfigurationException$sub_nonrefs;
typedef struct _jc_javax_xml_parsers_ParserConfigurationException$refs	_jc_javax_xml_parsers_ParserConfigurationException$refs;
typedef struct _jc_javax_xml_parsers_ParserConfigurationException$nonrefs	_jc_javax_xml_parsers_ParserConfigurationException$nonrefs;
typedef struct _jc_javax_xml_parsers_ParserConfigurationException$object	_jc_javax_xml_parsers_ParserConfigurationException$object;

typedef const struct _jc_javax_xml_parsers_ParserConfigurationException$vmethods	_jc_javax_xml_parsers_ParserConfigurationException$vmethods;
typedef const struct _jc_javax_xml_parsers_ParserConfigurationException$vtable	_jc_javax_xml_parsers_ParserConfigurationException$vtable;
typedef const struct _jc_javax_xml_parsers_ParserConfigurationException$vtype	_jc_javax_xml_parsers_ParserConfigurationException$vtype;

// Constructors
extern void _jc_javax_xml_parsers_ParserConfigurationException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_parsers_ParserConfigurationException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_parsers_ParserConfigurationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_xml_parsers_ParserConfigurationException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_xml_parsers_ParserConfigurationException$vmethods {
};

// Vtable
struct _jc_javax_xml_parsers_ParserConfigurationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_xml_parsers_ParserConfigurationException$vmethods	javax_xml_parsers_ParserConfigurationException;
};

// Vtype
struct _jc_javax_xml_parsers_ParserConfigurationException$vtype {
	_jc_type			type;
	_jc_javax_xml_parsers_ParserConfigurationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_parsers_ParserConfigurationException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_parsers_ParserConfigurationException$refs {
    _jc_javax_xml_parsers_ParserConfigurationException$sub_refs	javax_xml_parsers_ParserConfigurationException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_parsers_ParserConfigurationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_parsers_ParserConfigurationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_xml_parsers_ParserConfigurationException$sub_nonrefs	javax_xml_parsers_ParserConfigurationException;
};

// Object instance structure
struct _jc_javax_xml_parsers_ParserConfigurationException$object {
	_jc_javax_xml_parsers_ParserConfigurationException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_parsers_ParserConfigurationException$vtype	*vtype;
	_jc_javax_xml_parsers_ParserConfigurationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_parsers_ParserConfigurationException$vtype _jc_javax_xml_parsers_ParserConfigurationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_parsers_ParserConfigurationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_parsers_ParserConfigurationException$class_object;

#endif	/* _JC_javax_xml_parsers_ParserConfigurationException_H_ */
